The [leaflet plugin](#$:/plugins/sycom/leaflet) is a work in progress integration of the [leaflet][leaflet] library in TiddlyWiki in order to display geographical purpose tiddlers.

Have a look at [demo page on the web][plugindemo] or at integrated documentation which describes usage and examples.

Keep in mind that the plugin might be buggy or imperfect. Please [report any comment or issue][issues] on main repo.

## Sources / licenses
* [leaflet][leaflet] library (_1.3.1_) - License 2-clause BSD
    * leaflet-[markerCluster][markercluster] extension - Licence MIT
* [leaflet plugin][source] is released under similar [BSD 3-Clause license][license] as TiddlyWiki.
!! Side projects

[plugindemo]: https://sycom.gitlab.io/TiddlyWiki-Plugins/#Michel%20Strogoff%20from%20the%20sky
[source]: https://framagit.org/sycom/TiddlyWiki-Plugins/plugins/sycom/leaflet
[issues]: https://framagit.org/sycom/TiddlyWiki-Plugins/issues
[leaflet]: http://leafletjs.com/
[markercluster]: https://github.com/Leaflet/Leaflet.markercluster
[license]: https://framagit.org/sycom/TiddlyWiki-Plugins/LICENSE.md
